==> wikindx3_2_2.tar.gz: wikindx3/core/browse/BROWSECATEGORY.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2005
sirfragalot@users.sourceforge.net

**********************************************************************************/
/*****
* BROWSECATEGORY class
*
* Browse categories as a 'tag cloud'
*
* 
$Header: /cvsroot/wikindx/wikindx3/core/browse/BROWSECATEGORY.php,v 1.4 2005/12/20 07:36:22 sirfragalot Exp $
*****/
class BROWSECATEGORY
{
// Constructor
	function BROWSECATEGORY($db)
	{
		$this->db = $db;
		include_once("core/html/MISC.php");
		include_once("core/html/HTML.php");
		$this->html = new HTML();
		include_once("core/messages/MESSAGES.php");
		$this->messages = new MESSAGES();
		include_once("core/template/TEMPLATE.php");
		$this->template = new TEMPLATE('content');
		include_once("core/browse/BROWSECOMMON.php");
		$this->common = new BROWSECOMMON($this->db);
		include_once("core/session/SESSION.php");
		$this->session = new SESSION();
	}
// display categories
	function display()
	{
		$this->template->setVar('heading', $this->messages->text("heading", "browseCategory"));
		$this->sum = $this->category = array();
		$this->getCategories();
		asort($this->sum);
		asort($this->category);
		$pString = MISC::p($this->bib, "hint") . 
			MISC::pBrowse($this->process(), "center");
		$this->template->setVar('body', $pString);
		return $this->template->process();
	}
// Process and display results
	function process()
	{
		$lowestSum = current($this->sum);
		$highestSum = end($this->sum);
		foreach($this->category as $id => $name)
		{
//			$name = str_replace(' ', "&nbsp;", $name);
			$name = $this->html->codeToHtml($name);
			list($red, $colour) = $this->common->colourText($lowestSum, $highestSum, $this->sum[$id]);
			$size = $this->common->sizeText($lowestSum, $highestSum, $red);
			$links[] = MISC::aBrowse($colour, $size, $name, "index.php?action=listCategoryProcess" . 
			htmlentities("&id=" . $id)) . "&nbsp;[" . $this->sum[$id] . "]";
		}
		return join("&nbsp; ", $links);
	}
// Get categoriesfrom db
	function getCategories()
	{
		list($condition, $bib) = $this->common->userBibCondition('WKX_resource_category');
		if($condition)
			$condition = " WHERE " . $condition;
		$recordset = $this->db->select(array('WKX_resource_category'), array('id', 'categories'), $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->collate($row);
		if($bib)
			$this->bib = $this->messages->text("user", "bibliography") . ": " . $bib;
		else if($this->session->getVar('setup_multiUser'))
			$this->bib = $this->messages->text("user", "bibliography") . ": " . 
				$this->messages->text("user", "masterBib");
	}
// Add categories to array and sum totals
	function collate($row)
	{
		foreach(split(",", $row['categories']) as $key => $value)
		{
			if($value)
				$categories[] = "$value";
		}
		if(!isset($categories))
			return FALSE;
		foreach($categories as $categoryId)
		{
			if(!array_key_exists($categoryId, $this->sum))
				$this->sum[$categoryId] = 1;
			else
				++$this->sum[$categoryId];
			$categoriesCondition[] = "'$categoryId'";
		}
		if(!isset($categoriesCondition))
			return;
		$categoriesCondition = array_unique($categoriesCondition);
		$condition = $this->db->formatField('id') . "=" . join(" OR " .
			$this->db->formatField('id') . "=", $categoriesCondition);
		$recordset = $this->db->select(array('WKX_category'), array("id", "category"), 
			" WHERE " . $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->category[$row['id']] = stripslashes($row['category']);
	}
}
?>

==> wikindx3_3_1.tar.gz: wikindx3/core/browse/BROWSECATEGORY.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

The WIKINDX Team 2005
sirfragalot@users.sourceforge.net

**********************************************************************************/
/*****
* BROWSECATEGORY class
*
* Browse categories as a 'tag cloud'
*
* 
$Header: /cvsroot/wikindx/wikindx3/core/browse/BROWSECATEGORY.php,v 1.7 2006/04/29 00:44:45 sirfragalot Exp $
*****/
class BROWSECATEGORY
{
// Constructor
	function BROWSECATEGORY($db, $vars)
	{
		$this->db = $db;
		$this->vars = $vars;
		include_once("core/html/MISC.php");
		include_once("core/html/HTML.php");
		$this->html = new HTML();
		include_once("core/messages/MESSAGES.php");
		$this->messages = new MESSAGES();
		include_once("core/template/TEMPLATE.php");
		$this->template = new TEMPLATE('content');
		include_once("core/browse/BROWSECOMMON.php");
		$this->common = new BROWSECOMMON($this->db);
		include_once("core/session/SESSION.php");
		$this->session = new SESSION();
	}
// display categories
	function display()
	{
		$this->template->setVar('heading', $this->messages->text("heading", "browseCategory"));
		$this->sum = $this->category = array();
		$this->getCategories();
		natcasesort($this->sum);
		natcasesort($this->category);
		$this->category = $this->common->paging($this->vars, $this->category);
		$pString = MISC::p($this->bib, "hint") . $this->common->linksInfo() . 
			MISC::pBrowse($this->process(), "center");
		$this->template->setVar('body', $pString);
		$this->template->setVar('paging', $this->common->pagingLinks("action=browseCategory"));
		return $this->template->process();
	}
// Process and display results
	function process()
	{
		$lowestSum = current($this->sum);
		$highestSum = end($this->sum);
		foreach($this->category as $id => $name)
		{
//			$name = str_replace(' ', "&nbsp;", $name);
			$name = $this->html->codeToHtml($name);
			list($red, $colour) = $this->common->colourText($lowestSum, $highestSum, $this->sum[$id]);
			$size = $this->common->sizeText($lowestSum, $highestSum, $red);
			$links[] = MISC::aBrowse($colour, $size, $name, "index.php?action=listCategoryProcess" . 
			htmlentities("&id=" . $id)) . "&nbsp;[" . $this->sum[$id] . "]";
		}
		return join("&nbsp; ", $links);
	}
// Get categoriesfrom db
	function getCategories()
	{
		list($condition, $bib) = $this->common->userBibCondition('WKX_resource_category');
		if($condition)
			$condition = " WHERE " . $condition;
		$recordset = $this->db->select(array('WKX_resource_category'), array('id', 'categories'), $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->collate($row);
		if($bib)
			$this->bib = $this->messages->text("user", "bibliography") . ": " . $bib;
		else if($this->session->getVar('setup_multiUser'))
			$this->bib = $this->messages->text("user", "bibliography") . ": " . 
				$this->messages->text("user", "masterBib");
	}
// Add categories to array and sum totals
	function collate($row)
	{
		foreach(split(",", $row['categories']) as $key => $value)
		{
			if($value)
				$categories[] = "$value";
		}
		if(!isset($categories))
			return FALSE;
		foreach($categories as $categoryId)
		{
			if(!array_key_exists($categoryId, $this->sum))
				$this->sum[$categoryId] = 1;
			else
				++$this->sum[$categoryId];
			$categoriesCondition[] = "'$categoryId'";
		}
		if(!isset($categoriesCondition))
			return;
		$categoriesCondition = array_unique($categoriesCondition);
		$condition = $this->db->formatField('id') . "=" . join(" OR " .
			$this->db->formatField('id') . "=", $categoriesCondition);
		$recordset = $this->db->select(array('WKX_category'), array("id", "category"), 
			" WHERE " . $condition);
		while($row = $this->db->loopRecordSet($recordset))
			$this->category[$row['id']] = preg_replace("/{(.*)}/U", "$1", stripslashes($row['category']));
	}
}
?>
